@@ -17,9 +17,10 @@ from svtplay_dl.subtitle import subtitle
 from svtplay_dl.output import filename
 from svtplay_dl.postprocess import postprocess
 
-from svtplay_dl.service.aftonbladet import Aftonbladet
+from svtplay_dl.service.aftonbladet import Aftonbladet, Aftonbladettv
 from svtplay_dl.service.bambuser import Bambuser
 from svtplay_dl.service.bigbrother import Bigbrother
+from svtplay_dl.service.cmore import Cmore
 from svtplay_dl.service.dbtv import Dbtv
 from svtplay_dl.service.disney import Disney
 from svtplay_dl.service.dplay import Dplay
@@ -56,12 +57,14 @@ from svtplay_dl.service.viasatsport import Viasatsport
 from svtplay_dl.service.vimeo import Vimeo
 from svtplay_dl.service.youplay import Youplay
 
-__version__ = "1.9.4"
+__version__ = "1.9.6"
 
 sites = [
     Aftonbladet,
+    Aftonbladettv,
     Bambuser,
     Bigbrother,
+    Cmore,
     Dbtv,
     Disney,
     Dplay,
@@ -434,6 +437,9 @@ def main():
                       help="Remux from one container to mp4 using ffmpeg or avconv")
     parser.add_option("--include-clips", dest="include_clips", default=False, action="store_true",
                       help="include clips from websites when using -A")
+    parser.add_option("--cmore-operatorlist", dest="cmoreoperatorlist", default=False, action="store_true",
+                      help="show operatorlist for cmore")
+    parser.add_option("--cmore-operator", dest="cmoreoperator", default=None, metavar="operator")
                       
     (options, args) = parser.parse_args()
     if not args:
@@ -455,6 +461,11 @@ def main():
         options.silent = True
     setup_log(options.silent, options.verbose)
 
+    if options.cmoreoperatorlist:
+        c = Cmore(options, args)
+        c.operatorlist()
+        sys.exit(0)
+
     if options.flexibleq and not options.quality:
         log.error("flexible-quality requires a quality")
         sys.exit(4)
@@ -501,4 +512,6 @@ def mergeParserOption(options, parser):
     options.get_raw_subtitles = parser.get_raw_subtitles
     options.convert_subtitle_colors = parser.convert_subtitle_colors
     options.include_clips = parser.include_clips
+    options.cmoreoperatorlist = parser.cmoreoperatorlist
+    options.cmoreoperator = parser.cmoreoperator
     return options
