@@ -44,10 +44,18 @@ class LiveHDSException(HDSException):
 def hdsparse(options, res, manifest):
     streams = {}
     bootstrap = {}
-    if res.status_code == 403 or res.status_code == 404:
-        streams[0] = ServiceError("Can't read HDS playlist.")
+
+    if not res:
+        return None
+
+    if res.status_code >= 400:
+        streams[0] = ServiceError("Can't read HDS playlist. {0}".format(res.status_code))
         return streams
-    xml = ET.XML(res.text)
+    data = res.text
+    if is_py2 and isinstance(data, unicode):
+        data = data.encode("utf-8")
+
+    xml = ET.XML(data)
 
     if is_py2_old:
         bootstrapIter = xml.getiterator("{http://ns.adobe.com/f4m/1.0}bootstrapInfo")
