@@ -20,7 +20,7 @@ class Bambuser(Service, OpenGraphThumbMixin):
             yield ServiceError("Can't find video id in url")
             return
 
-        if self.exclude(self.options):
+        if self.exclude():
             yield ServiceError("Excluding video")
             return
 
