@@ -13,7 +13,7 @@ from svtplay_dl.fetcher.hds import hdsparse
 from svtplay_dl.subtitle import subtitle
 from svtplay_dl.error import ServiceError
 from svtplay_dl.utils.urllib import urlparse, urljoin
-
+from svtplay_dl.utils import is_py3
 
 class Dr(Service, OpenGraphThumbMixin):
     supported_domains = ['dr.dk']
@@ -79,24 +79,29 @@ class Dr(Service, OpenGraphThumbMixin):
             newstyle = '_' in encpath
             if newstyle:
                 encbasepath = encpath.split('_')[0]
-                path = base64.b64decode(encbasepath + '===')
+                path = base64.b64decode(encbasepath + '===').decode('latin1') if is_py3 else\
+                       base64.b64decode(encbasepath + '===')
             else:
-                path = base64.b64decode(encpath + '===')
+                path = base64.b64decode(encpath + '===').decode('latin1') if is_py3 else\
+                       base64.b64decode(encpath + '===')
 
             if '/view/' in path:
                 continue
 
             params = 'offset=0&limit=1000'
             if newstyle:
-                encparams = base64.b64encode(params).rstrip('=')
+                encparams = base64.b64encode(params.encode('latin1')).decode('latin1').rstrip('=') if is_py3 else \
+                            base64.b64encode(params).rstrip('=')
                 encpath = '%s_%s' % (encbasepath, encparams)
             else:
                 path = '%s?%s' % (urlparse(path).path, params)
-                encpath = base64.b64encode(path).rstrip('=')
+                encpath = base64.b64encode(path.encode('latin1')).decode('latin1').rstrip('=') if is_py3 else\
+                          base64.b64encode(path).rstrip('=')
 
             url = urljoin('https://www.dr.dk/tv/partial/',
                           '%s/%s' % (enccomp, encpath))
-            data = self.http.request('get', url).content
+            data = self.http.request('get', url).content.decode('latin1') if is_py3 else\
+                   self.http.request('get', url).content
 
             matches = re.findall(r'"program-link" href="([^"]+)">', data)
             episodes = [urljoin('https://www.dr.dk/', url) for url in matches]
