@@ -38,7 +38,7 @@ class Vg(Service, OpenGraphThumbMixin):
             else:
                 self.options.output = title
 
-        if self.exclude(self.options):
+        if self.exclude():
             yield ServiceError("Excluding video")
             return
 
